<?php

add_action( 'admin_init', 'dark_theme_options_init' );
add_action( 'admin_menu', 'dark_theme_options_add_page' );

/**
 * Init theme options to white list our options
 */
function dark_theme_options_init(){
	register_setting( 'dark_options', 'dark_theme_options', 'dark_theme_options_validate' );
}

/**
 * Load up the menu page
 */
function dark_theme_options_add_page() {
	add_theme_page( __( 'Theme Options' ), __( 'Theme Options' ), 'edit_theme_options', 'dark_theme_options', 'dark_theme_options_do_page' );
}


/**
 * Create the options page
 */
function dark_theme_options_do_page() {

	if ( ! isset( $_REQUEST['updated'] ) )
		$_REQUEST['updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Theme Options', 'mt-dark' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'mt-dark' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'dark_options' ); ?>
			<?php $options = get_option( 'dark_theme_options' ); ?>

			<table class="form-table">

								
				 <tr valign="top"><th scope="row"><?php _e('Name', 'mt-dark'); ?></th>
					<td>
						<input id="dark_theme_options[name]" class="regular-text" type="text" name="dark_theme_options[name]" value="<?php esc_attr_e( $options['name'] ); ?>" />
					</td>
				</tr>
				
				 <tr valign="top"><th scope="row"><?php _e('Photo', 'mt-dark'); ?></th>
					<td>
						<input id="dark_theme_options[photo]" class="regular-text" type="text" name="dark_theme_options[photo]" value="<?php esc_attr_e( $options['photo'] ); ?>" />
						<label class="description" for="dark_theme_options[photo]"><?php _e('Link to your image(80x80px)', 'mt-dark'); ?></label>
					</td>
				</tr>
				
				 <tr valign="top"><th scope="row"><?php _e('Description', 'mt-dark'); ?></th>
					<td>
						<textarea rows="12" cols="39" id="dark_theme_options[description]" class="regular-text" type="text" name="dark_theme_options[description]" value="<?php esc_attr_e( $options['description'] ); ?>" ><?php esc_attr_e( $options['description'] ); ?></textarea>
					</td>
				</tr>
								
							
			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e('Save Options', 'mt-dark'); ?>" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function dark_theme_options_validate( $input ) {
	// Say our text option must be safe text with no HTML tags
	$input['name'] = wp_filter_nohtml_kses( $input['name'] );
	$input['photo'] = wp_filter_nohtml_kses( $input['photo'] );
	$input['description'] = wp_filter_nohtml_kses( $input['description'] );
	return $input;
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/